Module mlme

Module mlme 

Structs

AssociationResponse
MacConfig
MAC attributes the network layer programs (see Mlme::configure).
PanDescriptor
ScanResult
StackProfile
Stack Profile field
ZigbeeBeacon

Enums

MacError
ScanType

Constants

A_BASE_SLOT_DURATION
A_BASE_SUPER_FRAME_DURATION
A_MAX_FRAME_RETRIES
The maximum number of retries allowed after a transmission failure (i.e. a missing acknowledgment). See IEEE 802.15.4-2003 7.4.2 (aMaxFrameRetries).
A_NUM_SUPER_FRAME_SLOTS
A_RESPONSE_WAIT_TIME
The maximum time, in symbols, a device shall wait for a response command to be available following a request command. See IEEE 802.15.4-2003 7.4.2. aResponseWaitTime = 32 * aBaseSuperframeDuration = 32 * 960 = 30720 symbols.
MAX_IEEE802154_CHANNELS
MAX_PAN_DESCRIPTOR_SIZE

Traits

Mlme
MAC sub-layer management entity.

Type Aliases

PanDescriptorList